@@ -102,7 +102,10 @@ def param_value(value):
     """
     if isinstance(value, SEQUENCE_TYPES):
         return q_join(value)
-    return dquote(value)
+    elif isinstance(value, str):
+        return dquote(value)
+    else:
+        return dquote(value.to_ical().decode(DEFAULT_ENCODING))
 
 
 # Could be improved
